Release History
===============

0.1.3
-----

Progress release. VOC is able to run Toga tutorials on Android.

0.1.2
-----

Progress release. VOC is able to compile the Toga and Colosseum libraries.

0.1.1
-----

Switched approach to parse Python code with ``ast`` instead of transpiling
CPython bytecode.

Many bugs fixed.

0.1.0
-----

Progress release. VOC is currently able to compile a simple working Android
application.

0.0.1
-----

Initial public release.
